==> haskell-base-unicode-symbols-0.2.2.4-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-base-unicode-symbols.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: base-unicode-symbols
version: 0.2.2.4
id: base-unicode-symbols-0.2.2.4-JhIFFGSwGTkfyE9ujSHul
key: base-unicode-symbols-0.2.2.4-JhIFFGSwGTkfyE9ujSHul
license: BSD3
copyright: 2009–2011 Roel van Dijk <vandijk.roel@gmail.com>
maintainer: Roel van Dijk <vandijk.roel@gmail.com>
stability: provisional
homepage: http://haskell.org/haskellwiki/Unicode-symbols
synopsis: Unicode alternatives for common functions and operators
description:
    This package defines new symbols for a number of functions,
    operators and types in the base package.
    .
    All symbols are documented with their actual definition and
    information regarding their Unicode code point. They should be
    completely interchangeable with their definitions.
    .
    For further Unicode goodness you can enable the @UnicodeSyntax@
    language extension \[1\]. This extension enables Unicode characters
    to be used to stand for certain ASCII character sequences,
    i.e. &#x2192; instead of @->@, &#x2200; instead of @forall@ and many
    others.
    .
    Original idea by P&#xE9;ter Divi&#xE1;nszky.
    .
    \[1\] <http://www.haskell.org/ghc/docs/latest/html/users_guide/syntax-extns.html#unicode-syntax>
author: Roel van Dijk <vandijk.roel@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Control.Applicative.Unicode Control.Arrow.Unicode
    Control.Category.Unicode Control.Monad.Unicode Data.Bool.Unicode
    Data.Eq.Unicode Data.Foldable.Unicode Data.Function.Unicode
    Data.List.Unicode Data.Monoid.Unicode Data.Ord.Unicode
    Prelude.Unicode
abi: 7c24478ee94ea99b0cbc2043901f78a5
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/base-unicode-symbols-0.2.2.4
library-dirs: /usr/lib/ghc-8.2.1/site-local/base-unicode-symbols-0.2.2.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/base-unicode-symbols-0.2.2.4
hs-libraries: HSbase-unicode-symbols-0.2.2.4-JhIFFGSwGTkfyE9ujSHul
depends:
    base-4.10.0.0
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
haddock-interfaces: /usr/share/doc/haskell-base-unicode-symbols/html/base-unicode-symbols.haddock
haddock-html: /usr/share/doc/haskell-base-unicode-symbols/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-base-unicode-symbols-0.2.2.4-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-base-unicode-symbols.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: base-unicode-symbols
version: 0.2.2.4
id: base-unicode-symbols-0.2.2.4-5S5alRFlq9h8rWVSfYKtGd
key: base-unicode-symbols-0.2.2.4-5S5alRFlq9h8rWVSfYKtGd
license: BSD3
copyright: 2009–2011 Roel van Dijk <vandijk.roel@gmail.com>
maintainer: Roel van Dijk <vandijk.roel@gmail.com>
stability: provisional
homepage: http://haskell.org/haskellwiki/Unicode-symbols
synopsis: Unicode alternatives for common functions and operators
description:
    This package defines new symbols for a number of functions,
    operators and types in the base package.
    .
    All symbols are documented with their actual definition and
    information regarding their Unicode code point. They should be
    completely interchangeable with their definitions.
    .
    For further Unicode goodness you can enable the @UnicodeSyntax@
    language extension \[1\]. This extension enables Unicode characters
    to be used to stand for certain ASCII character sequences,
    i.e. &#x2192; instead of @->@, &#x2200; instead of @forall@ and many
    others.
    .
    Original idea by P&#xE9;ter Divi&#xE1;nszky.
    .
    \[1\] <http://www.haskell.org/ghc/docs/latest/html/users_guide/syntax-extns.html#unicode-syntax>
author: Roel van Dijk <vandijk.roel@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Control.Applicative.Unicode Control.Arrow.Unicode
    Control.Category.Unicode Control.Monad.Unicode Data.Bool.Unicode
    Data.Eq.Unicode Data.Foldable.Unicode Data.Function.Unicode
    Data.List.Unicode Data.Monoid.Unicode Data.Ord.Unicode
    Prelude.Unicode
abi: d64e813a02a40130dd55942d18e11638
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/base-unicode-symbols-0.2.2.4
library-dirs: /usr/lib/ghc-8.2.2/site-local/base-unicode-symbols-0.2.2.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/base-unicode-symbols-0.2.2.4
hs-libraries: HSbase-unicode-symbols-0.2.2.4-5S5alRFlq9h8rWVSfYKtGd
depends:
    base-4.10.1.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
haddock-interfaces: /usr/share/doc/haskell-base-unicode-symbols/html/base-unicode-symbols.haddock
haddock-html: /usr/share/doc/haskell-base-unicode-symbols/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
